On the nonexistence of a strong minimal pairThanks: Peng’s research was partially supported by NSF of China No. 12271264. Yang’s research was partially supported by NUS grant WBS: R-146-000-337-114
Abstract.
Two nonzero recursively enumerable (r.e.) degrees and form a strong minimal pair if and for any nonzero r.e. degree . We prove that there is no strong minimal pair in the r.e. degrees. Our construction goes beyond the usual -priority arguments and we give some evidence to show that it needs -priority arguments.
Key words and phrases:
r.e. degrees, minimal pair2020 Mathematics Subject Classification
03D251. Introduction
In paper [1], Barmpalias, Cai, Lempp and Slaman claimed the existence of a strong minimal pair. Two nonzero recursively enumerable (r.e.) degrees and form a strong minimal pair if and for any nonzero r.e. degree , . The notion of strong minimal pairs can also be viewed as a strengthening of the so-called “Slaman triples”. Recall that three r.e. degrees and form a Slaman triple if , and for any nonzero r.e. degree , . In a Slaman triple formed by , and , it is clear that and form a minimal pair; if and coincide, then and will form a strong minimal pair.
We refer the readers to [1] for the significance of this study, as well as for its “long and twisted” history. Their paper was devoted to show the existence of a strong minimal pair, where they gave a detailed illustration of how to combine two sets of requirements before proceeding to the long and complicated full construction. They also raised the open question whether there exists a “two-sided” strong minimal pair—a strong minimal pair as above but with the extra clause “and for any nonzero r.e. degree , ”?
While trying to settle the existence of a two-sided strong minimal pair, we encountered a serious difficulty of dealing with three sets of requirements. It turns out that their original construction cannot overcome this difficulty either. Eventually, there is another twist in the history of the problem. By employing three families of r.e. sets, we are able to establish the nonexistence of a strong minimal pair:
Theorem 1.1 (Main).
For any r.e. degrees and , either or there exists an r.e. degree such that and .
As an immediate consequence, the degrees and in a Slaman triple cannot coincide; in fact, and also form a minimal pair. To see this, suppose toward a contradiction that there exists some nonzero r.e. degree below both and . Consider any nonzero r.e. degree below , we would have and therefore , which implies that and form a strong minimal pair, contradicting our main theorem. This fact echoes the gap-cogap construction used in building a Slaman triple (see, for example, Shore and Slaman [3]), where elements are enumerated into and at alternating stages.
Besides the strong minimal pair problem itself, we are also interested in the techniques involved in the solution. In the paper [1], a novel -outcome was introduced to handle some of the conflicts in a way that goes beyond -priority method. In this paper, we use an -branching tree to organize our construction, furthermore, each -st branch can be considered as a gateway to a parallel -world. A similar design has been used before, notably by Shore in [2]. However, the conflicts between our strategies seem more severe than those in Shore’s. For instance, for certain two nodes on the priority tree, one inside a -world, the other outside, we cannot determine a priori which node has higher priority; we have to assign priority dynamically: whichever acts first will change the environment of the other. Much more care has to be applied in showing the existence of the true path. This brings up the question of what counts as a typical -priority argument. A -priority argument can now be routinely presented in a framework where finite injuries happen on the true path. Our construction seems to suggest that handling the interactions inside and outside the -world must be a feature in any framework for a -priority argument. We hope that our work will bring us closer to a canonical framework for the -priority argument.
2. Toward the stage by stage construction
2.1. Preliminaries and conventions
A Turing functional is an r.e. set of of triples, called the axioms, such that if both , and , then . We write if ; in this case, we also define the use function to be the least such plus 1. We write if . By assuming that Turing functionals are computing initial segments, we may further assume that the domain of a given Turing function is downward closed, and its use function is nondecreasing with respect to its arguments. For two subsets and of natural numbers, we write if there exists a Turing functional such that for each , . Following the assumption above, whenever we write , we mean for all . We will use to indicate that all calculations are restricted to a particular stage , and in particular, all numerical parameters occurred are .
For , the length of agreement at stage is defined as
We say that is an expansionary stage if for all .
We define if and only if
says that the set up to the first digits does not change from stage to .
2.2. Requirements
Given r.e. sets and with , we build an r.e. set satisfying the following requirements:
The first one is the permitting requirement:
- •
: .
Fix an effective enumeration of Turing functionals , we have the diagonalization requirements, here the letters and come from and respectively:
- •
: ; and
- •
: .
has three possible outcomes: Case (1), there is an such that never agrees with ; Case (2), there is a divergent point such that as ; and Case (3), .
The strategy of is to check if the length of agreement between and goes to infinity. If the answer is no, then we win by the -outcome which is Case (1). If the answer is yes, we have a -outcome indicating either Cases (2) or (3). Then we try to build a Turing functional so that
In a usual priority argument, if turns out to be partial, then we shall exhibit a divergent point of as in Case (2); however, in our construction we might also have the possibility of Case (3) and we shall begin to work on another set instead of —we take a nonuniform approach. In fact, instead of constructing a single r.e. set , we construct three types of candidates whose types are denoted by , and . There will be a unique candidate for a -set, which will be denoted by . There will be countably many candidates each for -sets and -sets and will be denoted by or where the subscripts refer to their “parent nodes”. We will argue that at least one of these candidates satisfies all requirements.
2.3. Priority tree
Fix a list of requirements as
where stands for a candidate that we build. Depending on whether is a -set, -set or -set, the strategies will be different. Besides the nodes that work directly for our requirements, we also have other auxiliary nodes.
The priority tree is defined recursively as follows. The root of is assigned to . A node assigned to will be called a -node. A node is said to be in the -world if it is not declared to be in a -world (see 5 below). For references, the first few nodes of the priority tree are given in Figure 1, where we also omit some of the outcomes, particularly those with label “”, to save space.
Suppose that has been assigned.
- (T1)
Suppose that is a -node, then has a unique outgoing edge labelled and is assigned to .
Remark.
A -node is the place where we introduce a new candidate and is the only place where we enumerate numbers into . The permitting is done in a delayed fashion, after a number gets permitted by , its fate will be determined only by the next -stage. After introducing the set , we work on which is the first one in its requirement list.
- (2)
Suppose that is a -node, then it has two outgoing edges labelled , here means “to the left of”.
- (T2.1)
If , then is assigned to and to .
- (T2.2)
If for some , then is assigned to and to .
- (T2.3)
If for some , then is assigned to if is also in the -world, and to if is in a -world; is assigned to .
- (T2.1)
Remark.
A -node checks if the length of agreement of goes to infinity: if not, it has the -outcome and is satisfied easily, and we move on to the next requirement . One may view as a degenerated case, as the nodes extending can safely ignore . In the case that -node has the -outcome , we first introduce more sets to form a three element group . Only after we have for some and with , we introduce an -node to detect a divergent point for -functionals at either , , or . An -node is a degenerate case of , where we detect a divergent point for -functionals at either or . As one shall see, an -node necessarily lives in a -world where the set is no longer considered.
- (3)
Suppose that is a -node, then has three outgoing edges labelled .
- (T3.1)
If , then is assigned to where and is a finite set of nodes on the tree and will be defined later; and are both assigned to .
- (T3.2)
If , then is assigned to where and is a finite set of nodes on the tree and will be defined later; and are both assigned to .
- (T3.3)
If and is in the -world, then is assigned to ; if and is in a -world, then is assigned to . In both cases, and are assigned to .
- (T3.1)
Remark.
A -node first checks if it has some such that but . If so, has the -outcome and is satisfied in the easiest way. If not, checks if the length of agreement between and goes to infinity. The -outcome indicates that the length of agreement stops increasing from some stage onward; the -outcome indicates the other case. Below the -outcome, we do not try to diagonalize against immediately if . The reason is that usually showed up before some or nodes appear. We are ready to attack only when we teamed up this with either or for some . The decision of choosing which set to attack and why it works are the core of our construction and will be discussed later.
- (4)
Suppose that is an - or an -node, where , and are -, - and -nodes for some , and , respectively. Let and .
- (T4.1)
If is an -node, then has infinitely many outgoing edges, labelled and ordered by
Furthermore, for each , is assigned to , assigned to and assigned to .
- (T4.2)
If is an -node, then has infinitely many outgoing edges, labelled and ordered by
Furthermore, for each , is assigned to and assigned to .
is said to be a divergent outcome for ; a divergent outcome for ; and a divergent outcome for if is also an -node.
- (T4.1)
Remark.
A divergent outcome for indicates that we have some number , not necessarily (see Section 3 for the discussion on edge parameters), such that and is therefore satisfied. Extending -outcome, we shall begin to work for the next requirement in the requirement list. An -node is necessarily in the -world while -node is necessarily in a -world.
- (5)
Suppose that is a -node, then has infinitely many outgoing edges, labelled and ordered with order type by
Any extension of is declared to be in the -world of . Furthermore, is said to be a divergent outcome for and is assigned to , where comes from the index of the -node . is assigned to .
Remark.
At a -node we try to detect a divergent point of . If we find one, we continue to work on the next requirement ; otherwise, we shall not work for the candidate anymore; we switch to work for the candidate (together with some sets from ) by assigning to . Note that by 3(T3.3) there will be no more -node extending and therefore there will be no nested -worlds.
- (6)
Suppose that is an -node, where is a -node for some . Let . Then has infinitely many outgoing edges labelled and ordered by
Furthermore, is said to be a divergent outcome for and for each , is assigned to .
Remark.
An -node is necessarily in the -world for some -node with . At , we try to detect a divergent point of . If we find one, we shall work on the next requirement . If the detection fails, we shall conclude that toward a contradiction.
- (7)
Suppose that is a -node. Then is a terminal node on the priority tree. We let as has been defined in 3(T3.1). For each where is a -node, we enumerate into .
- (8)
Suppose that is a -node. Then is a terminal node on the priority tree. We let as has been defined in 3(T3.2). For each where is an -node, we enumerate into .
Remark.
A -node will produce many potential diagonalizing witnesses for or , each of whom is a -node. And bets that will permit some of the diagonalizing witnesses eventually. If never permits, then will demonstrate to be recursive toward a contradiction. Otherwise, one of the -node reaches a -outcome and is satisfied forever. Consequently, the -node is switched off true path. Similar discussion applies to a -node.
This finishes the definition of the priority tree .
Lemma 2.1.
Let be an infinite path along . Then there is a (unique) such that , and for each , and are assigned to some node in . Moreover, for this , if is assigned to , then either
- (1)
, or
- (2)
and there is some such that where is the divergent outcome for ;
if is assigned to , then either or is in .
Proof.
A set wanted by the lemma is said to be good.
Along the infinite path , it is clear that if , then ; if , then ; if and there is some such that where is the divergent outcome for , then . Also note that and as both are assigned to either a - or a -node, which are terminal nodes, contradicting that is infinite.
Clearly the root is assigned to . Suppose that is not good, then for some assigned to for some , we must have that but no divergent outcome for can be found in . Note that is assigned to . Suppose that is not good, then for some assigned to for some we must have that but no divergent outcome for can be found in . Note that is assigned to . We claim that is good.
Case 1. Suppose . Then by 3(T3.3), is either an -node or a -node. However, by 5, 6, and the assumption that no divergent outcome for either or can be found in , we have a contradiction. Therefore if , then or is in .
Case 2. Suppose . Then by 2(T2.3), is either an -node or an -node. We should have . That is, if , then .
Hence is good. ∎
Remark.
We did not formally associate explicit “requirements” to the type of nodes labelled and . If we do, the requirement associated with -node would be:
similarly for and -nodes. The requirements associated with -node would be:
where is the unique -node in and is the index ; and the missing parameters in can be found precisely because each is necessarily a -node, similarly for -nodes. The -nodes can be better viewed as to detect if is total where is the index of the Gamma functional at , which is part of strategy to satisfy . In this sense, a -node plays the analog role of a -node on the tree which detects if there are infinitely many expansionary stages. From these examples, it is clear that the formalism would often involve several sets and functionals whose indices can only be found in a rather complicated way, which would not provide any further insight.
On the other hand, without spilling out the requirements associated with -nodes, we can still verify the correctness of the construction as follows: First establish the existence of an (infinite) true path ; then obtain the set given by Lemma 2.1 from ; finally argue that requirements , and , as stated in subsection 2.2, are all satisfied for this . In this way, the requirements associated with -nodes are involved only indirectly.
From now on, we will not pay attention to the index in a -node or a -node: if is a -node, we will write for and for ; if is a -node, we will write for . As there will be no ambiguities, will be abbreviated as if is a -node. We leave the notation of -outcome as it is.
Definition 2.2.
If is a -node, we write
and
A node is in a -world if and only if there exists some -node such that .
We let denote the predecessor of , and we write if is a -node, a -node or a -node.
Definition 2.3.
Suppose that . If , then is the root of ; if for some , then ; if for some , then .
In other words, if , then is its “host” which is the -node where we introduced the set .
Definition 2.4.
Let be a -node for some . An -node with for some is said to have conflicts with (or equivalently, has conflicts with ).
Let collects each that has conflicts with .
Remark.
The relation between and some can be loosely stated as follows. We would like to diagonalize at with some witness targeting . But we will see that this must be paired with some other witness or targeting or respectively. Whether is chosen (discarded) or one of is chosen (discarded) will depend on what happens at those . Note that can be empty.
Now we discuss some structural properties of the priority tree . By 5, we have the following
Lemma 2.5.
Let be an -node, then there is a unique -node such that . Moreover, is a -node for some and . ∎
Lemma 2.6.
Let be a -node. Then if and only if there exists a unique -node for some , , and such that .
Proof.
This lemma indicates where the non-uniformity comes in: those -nodes inside a -world have a choice to make when comes to diagonalization, whereas the nodes outside -worlds have no choice but to enumerate elements into .
The following two lemmas are clear from the definition of .
Lemma 2.7.
Let be a -node. Then for each with , . ∎
It says that if we have not satisfied yet, we stop working on other requirements for .
Lemma 2.8.
Let be a -node. For , is injective. ∎
We now postulate the global (or static) priority between the nodes on the priority tree. We use to denote that has higher global priority than . We mostly follow the left-to-right order on the priority tree.
Definition 2.9 (global priority).
Let be such that there exists some such that , and .
- (1)
If is not a -node, then we define .
- (2)
If is a -node but is not , then we define .
If or , we say and are -comparable.
If , we do not think that has higher priority than . Global priorities are similar to the usual priorities because they depend on the positions of the nodes on the tree. However, if is a -node and is , then we do not define between and ; a “dynamic” and “local” priority between these two will be defined in Definition 4.5. We call it “dynamic” because it depends on the pairs (which will be introduced in Subsection 4.4), which are not permanent and can be canceled. Moreover, even if is paired with , the priority between them can only be determined based on what happens on current stage.
The following lemma will be used in Lemma 5.4.
Lemma 2.10.
- (1)
If and are - and -nodes respectively, then they are -comparable.
- (2)
If and are - and -nodes, respectively, with , then they are -comparable.
Proof.
(1) holds as a -node never belongs to a -world.
For (2), we suppose toward a contradiction that there exists a -node such that and . It is clear then .
∎
3. Parameters
Unlike a usual priority argument, where we might have static parameters assigned to the edges of the priority tree, our construction has dynamic parameters; each node has to update them at the end of each stage. Two kinds of the parameters are edge parameters and pairing parameters and will be discussed first in this section.
We assume that the readers are familiar with usual tree constructions. We now describe how a given node maintains its parameters at the end of stage .
-node: Suppose and . For each and for each , the edge parameter is initially set to be . Let be the outcome such that is visited at , if any.
- (1)
If , we update and for each and each .
- (2)
If or , we do nothing.
If is initialized at stage , we set for each and each .
Remark.
If is stable (i.e., ), then the divergent outcome indicates that there is some such that . Other divergent outcomes are similar.
-node: Suppose and . For each , the edge parameter is initially set to be . Now at stage , let be such that is visited at stage . We update for each . If is initialized at stage , we set .
-node: For each , the edge parameter is initially set to be . Now at stage , let be such that is visited at stage , we update for each . If is initialized at stage , we set .
The above covers the nodes where edge parameters are needed. The next one concerns with pairing parameters.
-node: If , then it needs no pairing parameters. Now we assume that . By Lemma 2.6, we let be the (unique) -node with . The pairing parameter is defined to be the least number such that for each -node and each with (we assume that has been updated because ).
-nodes however need no pairing parameters. Other kinds of parameters are discussed below.
-node: -outcome of can be activated at some stage. Once it becomes activated, it remains activated forever (even if the node is initialized).
In our construction, an - or -node builds a functional , an -node builds a functional , a -node builds a functional , and a -node builds a functional (the symbol is reused). These functionals are built locally and hence will be referred as local parameters. Once a node is initialized or disarmed, its local parameters are discarded immediately.
A - or -node has to maintain a function (standing for diagonalizing witness). This is also referred as a local parameter. A -node (or -node, respectively) is where we attack the recursiveness of (or , respectively) or by enumerating a diagoalizing witness into one of them. The whole attacking process consists of four phases and is defined in the first phase:
- (Phase1)
Prepare the diagonalizing witnesses (Subsections 4.3 and 4.4). Without loss of generality, we assume that is a -node. has to prepare many diagonalizing witnesses for each hoping one of them gets permitted. To ensure that one of them get permitted, builds a functional so that in case none of them gets permitted. This would imply that is recursive toward the contradiction. The diagonalizing witnesses are organised in the following way: for each , is a map from to ; for each , is the diagonalizing witness targeting the set . We say that is prepared if . Thus, enumerating into leads to the -outcome of (and we activate in this case). Once is prepared for each , we define .
- (Phase2)
- (Phase3)
- (Phase4)
Enumerate the point (Subsection 4.11). Suppose that the chosen permission node is visited and the chosen diagonalizing point has not been canceled yet, we simply enumerate it into the and activate at the same moment (and will not be visited again).
4. Strategies and construction
When a node is visited, particular actions will be taken and will be described formally in the subroutine . In each of the following subsections, it describes either or other actions. We will freely use the terms true outcome and true path in the usual sense in an informal remarks. Though we have a slightly modified definition for true outcome and true path (Definition 5.1), the intuition behind them remains the same.
Definition 4.1.
Convention 4.2.
Whenever announces progress, each of lower global priority (Definition 2.9) is initialized tacitly. If is initialized, each extending is also initialized tacitly. In both cases, we say that initializes , or is initialized by .
Remark.
“Initialize” is used in the usual sense: when a node is initialized, all local parameters are discarded. “Disarm” can be thought of as an analogy of “initialize” and specially designed for -nodes (see Subsection 4.4).
4.1. G-node
Suppose that is a -node for some and the current stage is .
:
- (1)
If is an expansionary stage, then .
- (2)
Otherwise, .
Remark.
The job of is to measure the length of agreements between and . If the true outcome is -outcome, we end up with and is therefore satisfied. Note that having infinitely many expansionary stages does not guarantee . In fact, there could be some divergent point which will be detected by either -, - (or -) or -nodes, depending on whether is of type , or .
4.2. D-node
Suppose that is a -node for some and the current stage is .
:
- (1)
If -outcome is activated (see Subsection 4.11), then .
- (2)
If is an expansionary stage, then .
- (3)
Otherwise, .
Remark.
The main job of is to measure the length of agreements between and . As we shall see later that once -outcome becomes activated, it remains activated forever. If -outcome is the true outcome, then we are given a point such that and is therefore satisfied. If -outcome is the true outcome, then for some point , either or , which implies that is satisfied. If -outcome is the true outcome, then and hence is not satisfied. In this case, the set is not a good one in the sense of Lemma 2.1.
4.3. P-node
Suppose that is a -node and is being visited at stage . Let be the least -stage such that never gets initialized between and .
: Let be the least such that is not defined.
- (1)
If is not defined, we pick a fresh number for each and define . Stop the current stage.
- (2)
If is defined but for some we have (i.e., is not prepared), then we stop the current stage.
- (3)
Otherwise, we define . Stop the current stage.
Remark.
Basically, it just implements the (Phase1) to prepare the diagonalizing witnesses. In (2), it means although we expect infinitely many expansionary stages, yet the length of agreements has not reached . So we just wait. As -node is a terminal node, the true outcome does not matter. As we shall see later, if is on the true path, then we have for each ; hence, is recursive. To achieve this, whenever we have , we have to prevent from being visited again (i.e., switch it off the true path) by diagonalizing against some and activating . See Subsection 4.9 for details.
4.4. Q-node
Suppose that is a -node and is being visited at stage . Let be the least -stage such that never gets initialized or disarmed (see below) between and .
:
- (1)
- (2)
Suppose or that has been paired. Let be the least such that is not defined.
- (a)
Suppose that is not defined, we pick a fresh number for each and define . Stop the current stage.
- (b)
Suppose that is defined but for some we have . Stop the current stage.
- (c)
Otherwise, we define . Stop the current stage.
- (a)
Remark.
The action of has two parts: In (2), it prepares the diagonalizing witnesses like the -node above; in (1), it establishes a pair. - and -worlds will interact via such pairs, based on which a “local” “dynamic” priority will be defined (see Subsection 4.8, particularly Definition 4.5). Examples of pairs can be found in Figure 2, in which and are two pairs.
4.5. Pair
Suppose that is a pair established as in (1) in Subsection 4.4. We implement the following three rules:
- (P1)
We cancel the pair if and only if is initialized.
- (P2)
Whenever the pair is canceled, we initialize (and all nodes below by Convention 4.2).
- (P3)
Whenever announces progress (Definition 4.1), we initialize .
Note that the pair is not canceled when is disarmed (Subsection 4.12). A case of special importance shall be noted:
Lemma 4.3.
Let be a pair. Whenever is activated, is initialized.
Proof.
Definition 4.4.
For two pairs, we say that has higher pairing priority than if . (Note that if and only if .)
4.6. R-node
Suppose that is an -node or an -node and the current stage is . Let be the last -stage.
: Let .
- (1)
Suppose . We stop the current stage.
- (2)
Suppose . We proceed with .
- (3)
Suppose but .
- (a)
If , .
- (b)
(Ignored this line if is an -node) If (a) does not happen and , .
- (c)
If neither (a) nor (b) happens and , .
- (d)
Otherwise, we define with use for each with and then stop the current stage.
- (a)
- (4)
Otherwise, for each with , we define with a fresh use , particularly
- (a)
,
- (b)
(Ignore this line if is an -node) , and
- (c)
.
Then we proceed to .
- (a)
Remark.
The -node is responsible for defining , whose use is set to bound and . When becomes undefined (as in (3) above), we track the culprit and try to demonstrate (in that order) that , or is undefined. It is important to note that (4b) and (4c) are ensured only at the stage when we define ; the two conditions are allowed to be violated at other stages. The reader shall find details in Subsection 5.1.
4.7. S-node
Suppose that is an -node and the current stage is . Let be the last -stage.
: Let .
- (1)
Suppose . We stop the current stage.
- (2)
Suppose . We proceed with .
- (3)
Suppose but .
- (a)
If , then .
- (b)
Otherwise, we define with use for each with . Then we stop the current stage.
- (a)
- (4)
Otherwise, for each with , we define with a fresh use , particularly . Then we proceed to .
Remark.
The actions of -nodes are similar to those of -nodes. We define with use bounding . If is the true outcome, we can conclude that , which implies and a divergent point for is found. Unexpectedly we might end up with but . This may happen when with whereas does not say anything about . The success of an -node relies on the “totality” (in a less strict sense) of . Such reliance is the core of our construction and will be discussed in Subsection 5.2.
4.8. C-node and local dynamic priorities
Let be a -node. Before we describe at stage , we need to define the “local” “dynamic” priority which connects some pairs of nodes that one is in the - and the other is in the -worlds of . It contrasts the global priority (without subscripts) defined in Definition 2.9 which depends only on the priority tree. In the notation , the subscript corresponds to the “local” part and corresponds to the “dynamic” part.
Definition 4.5 (local priority).
For and (Note that and are not -comparable), we define as follows:
- (1)
if there exists some such that extends for some and ,
- (2)
if there exists some such that and extends for some .
(If the list is empty, then .)
Remark.
We will often write for short as the stage is usually clear from context. Note also that is a partial order; and can be -incomparable. However, if is a - or -node and is a -node that is paired, then either or .
In Figure 3, two pairs and are given. An arrow indicates if and lie in the same row; if they lie in different rows: labels along the arrows refer to corresponding items in Definition 4.5. For example, Item (1) of Definition 4.5 gives, without an explicit arrow in Figure 3, , which follows equivalently from . In a similar fashion, Item (2) of Definition 4.5 gives , and we might view this as a consequence of . Note that and are not -comparable. Although and are not -comparable, we observe that whenever announces progress, is initialized, and by (P1) (Subsection 4.5) the pair is canceled and by (P2) is therefore initialized (Lemma 4.3 is a special case of this phenomenon). Also, (P3) is justified by Item (2) of Definition 4.5.
With the definition of local dynamic priority, we are ready to describe for the -node .
: Let be the last -stage. Let be the least (if any) such that . We are ready to visit nodes in . We start with . Whenever we run into for , we interrupt the subroutine and do the following:
- (1)
If and has not been initialized, ; if and has been initialized, we stop the current stage. (After nodes in has been visited, we decide if we need to visit nodes in .)
- (2)
If , then . (We stop visiting nodes in .)
- (3)
If does not exist, without interruptions.
Remark.
At the -node, we are facing two parallel worlds which are connected via pairs. Instead of having two separated accessible path, we explore the two possibilities simultaneously. Whenever we see an interaction via a pair, we stay in the winner’s world. If we do not see any interaction, we do not bet as either world can be the winner; indeed, we visit both worlds simultaneously.
4.9. Permitting center
The permitting center is not represented on the tree. At the beginning of a stage , if we have for some , then some - or -node might have a problem because . cannot be corrected and we have to prevent from being visited again by diagonalizing against some “good” (whose existence is one of the most important parts of the verification) (if is a -node) or (if is a -node) and activating , which has higher global priority than . This section is to discuss how we choose this and this is done at the permitting center at the beginning of each stage.
Remark.
All tensions among nodes on the priority tree trace back to a defined by either a - or -node and a point such that .
Let be the root of the priority tree and be the current stage.
Permitting center:
- (1)
If there is no point with , we do nothing.
- (2)
(making choice) Let be such that . Let be the - or -node, if any, which has not received attention and . We list as where (the list is empty if ). We define the choice function by letting
for the least , if any, such that for each we have (see Subsection 4.10 for the definition of function)
if such does not exist (including the case when ),
- (3)
Let . We send the point to , which is the -node where .
If (2) happens, we say that receives attention (on at stage ).
Remark.
- (i)
For convenience, is allowed to receive attention only once since last initialization or disarmament.
- (ii)
There can exist at most one as desired in (2). To see this, let and be two - or -nodes who build and respectively. If both of them are -nodes (or -nodes), they are -comparable; otherwise, being terminal nodes, there must exist some such that and , say. By the remark below Definition 4.5, they are -comparable. Therefore, whenever we visit the node of higher global (or local) priority, the one of lower global (or local) priority is initialized or disarmed. Therefore, domains of and must be disjoint.
- (iii)
chooses the node such that we are allowed to enumerate the point into . However, we are not enumerating it into immediately; we will do so when we visit provided that has not been disarmed or initialized. The delay feature of the permitting is crucial to Lemma 5.3.
4.10. R-test
Intuitively, an -node would like to put a restraint on while . If a -node , for example, receives attention on , we are not free to enumerate the point into (where ): an -node may still have a restraint on . To tell in which situation an -node allows to be enumerated in a delayed fashion, we now introduce the function, which we have used without definition in Step (2) of permitting center. The following definition is a bit technical and the whole picture can only be seen in the verification section, particularly Subsection 5.1.
Definition 4.6 (R-test).
Let be an -node. Fix numbers and for some and . is assumed to be either a - or a -node with and .
Suppose that is a -node. For every , we define if one of the following holds
- (R-t1)
;
- (R-t2)
and ; or
- (R-t3)
, and , where is the last stage when we define .
Suppose that is a -node. We define if either (R-t1), (R-t2) or the following holds
- (4)
, and , where is the last stage when we define .
Define if for every we have .
Remark.
Informally, means that passed the test posed by so that the computation would not be affected by entering . Items (R-t1) and (R-t2) are natural, whereas items (R-t3) and 4 are toward that the computation is now “protected” by the - and -side respectively.
We could define if , but since we never use it, we leave it as it is.
If via (R-t2), then for each ; if via (R-t1), then for each . In fact, we have the following lemma to simplify the test, where the number in the lemma is also easy to determine.
Lemma 4.7.
At stage , let
Suppose , then .
4.11. Permit(X)-node
Suppose is a -node and the current stage is . Recall that at Step (3) of permitting center, some point was sent to a -node.
: Let be the point sent by permitting center (3), where , and . (We assume that is not discarded yet).
- (1)
We enumerate into and activate the -outcome of .
- (2)
Then .
4.12. Disarming process
Let be the current stage. Let be a -node with , be an -node, be the unique -node with , and is paired at some .
-DisarmingProcess: We disarm immediately if one of the following events is observed at stage :
- (DP-1)
At the permitting center, some - or -node extending with receives attention.
- (DP-2)
At -node, both and
hold, where is the last -stage when we define . - (DP-3)
At the node , the outcome to be visited is for some .
- (DP-4)
At the node , and for the last -stage we have either or .
- (DP-5)
At the end of the stage when we maintain the global parameters, .
If one of the events is observed, we say that -DisarmingProcess is triggered. The -DisarmingProcess lasts until is canceled.
When is disarmed, we discard its and . If there is a diagonalizing witness for some and having been sent to (as described in permitting center (3)), we also discard the diagonalizing witness .
Remark.
(DP-5) follows from (DP-1) and (DP-3) and we state it explicitly for convenience. In fact, (DP-2) needs a bit of justification. Since (DP-5) implies , in (DP-2) is legitimate. There could be multiple disarming processes but they are working independently respecting Convention 4.2. The latter part of (DP-4) is there only to prevent one from disarming infinitely often if .
4.13. Construction
At the beginning of stage , we let the permitting center acts and then where is the root of the priority tree . Meanwhile, the disarming processes are working in the background. We stop the current stage whenever with .
This is the end of the construction.
5. Verification
A path of a tree is a collection of nodes such that they are pairwise comparable and are closed under initial segments. The standard way to pick up the “true path” is to collect inductively those leftmost nodes that are visited infinitely often. In our construction, however, such nodes can be initialized infinitely often. Therefore we shall slightly modify the definition of the true path.
Definition 5.1.
Let be the priority tree and the construction be given as above. We define
where “injured” means “initialized or disarmed”. The leftmost infinite path of , if any, is the true path. For , -outcome is the true outcome if .
Clearly , is a two-branching (the labels are not recursive) tree by Convention 4.2, and is -recursive. In Lemma 5.11 we show that has an infinite path. In fact, can have multiple infinite paths, each of which is in fact as good as the true path — we just pick one in order to discuss the index of a winning set (Lemma 6.1).
In Subsections 5.1 and 5.2, we show that - and -nodes can actually work as intended at each stage. Therefore nodes in achieve their goals (Lemma 5.8). In Subsection 5.3, we argue that has an infinite path and all requirements for the set (given by Lemma 2.1) are satisfied.
5.1. Success of -strategies
We will not distinguish between an -node and an -node in this section: the following definition also applies to an -node. Lemma 5.4 is strictly easier to verify (more precisely, Case 1 does not happen).
Definition 5.2 (R-Condition).
Let be an -node. We say that -Condition holds at stage if either
- (1)
, or
- (2)
but where is the last stage when we define .
We say that -Condition holds if -Condition holds for each .
Whenever we define at a stage , holds at stage trivially.
The purpose of -Condition is to ensure the correctness of defined at :
Lemma 5.3 (R-Correctness).
Let be an -node, and assume that -Condition holds at every stage. For each -stage and each , if , then .
Proof.
Fix an -stage and a number such that [s] is defined. Let be the last -stage when we defined . Therefore we have
- (1)
,
- (2)
, and
- (3)
.
Furthermore, since -Condition holds, we also have
- (4)
.
Hence we have
By Lemma 5.3, it suffices to check that our construction ensures -condition.
Note that if via (R-t1) or (R-t2), enumerating into does not violate -condition; if via (R-t3), we will send to and will enumerate into whenever is visited unless is discarded.
Lemma 5.4 (R-Condition Satisfaction).
For each -node and each stage , -Condition holds.
Proof.
Let be an -node, and . Let be the last -stage when we defined . Suppose that we have but . Then we have
- (1)
,
- (2)
,
- (3)
, and
- (4)
for some , is enumerated into , say, at some (least) stage with .
We assume that at some stage with , receives attention due to (Phase3) of the attacking process for some .
Case 1. Suppose that is a -node (therefore is not an -node) and for some such that , and . From (4) we conclude that is visited at .
As , we conclude that extends for some and therefore
- (5)
(by the setting of Section 3).
Since at and hence , we must have (R-t3), which implies
- (6)
.
We observe that only -node can potentially enumerate a point into , and any two -nodes are always -comparable by Lemma 2.10. Also, no -node of higher global priority than receives attention between and , because otherwise would be initialized before we enumerate into at . Furthermore, any -node of lower global priority than is initialized at . By (1), is never visited between and . Therefore, , prepared by any lower global priority -node between and , must be larger than , hence, . Therefore we have . Together with (6), we have
- (7)
.
Note that . We have the following contradiction:
Case 2. (This case varies only slightly.) Suppose that is a -node and for some such that , and . For the same reason as in Case 1 we have
- (8)
.
Since at and hence , we must have 4, which implies
- (9)
.
To show , we first realize that only a -node with and potentially enumerates a point into the set . By Lemma 2.10, and are -comparable. Such -nodes of lower global priority than are initialized at and those of higher priorities, if received attention before or at the beginning of stage , would initialize . Therefore we have . Together with (), we conclude that
- (10)
Note that . We have the following contradiction:
5.2. Success of -strategies
Definition 5.5 (S-Condition).
Let be an -node. For each , we say that -Condition holds at stage if either
- (1)
, or
- (2)
but we also have the following: (Here, is the last stage when we defined .)
- (a)
If , then
. - (b)
If , then either
or .
- (a)
We say that -Condition holds if -Condition holds for each .
Remark.
The objective of the S-condition is to guarantee the correctness of the value of . This is done by ensuring is bigger than either or . In the case of Definition 5.5(2a), we have no choice but to prevent from changing, whereas in the case of (2b) we are more flexible and we can “preserve” either -side or -side, a situation similar to the minimal pair construction.
By a similar argument as in Lemma 5.3, one can prove the following:
Lemma 5.6 (S-Correctness).
Let be an -node. Assume that -Condition holds at every stage. Then for each -stage and each , if , then .
Proof.
Fix an -stage and a number such that is defined. Let be the last -stage when we defined . Therefore we have
- (1)
,
- (2)
, and
- (3)
.
By the assumption that -Condition holds, either Definition 5.5(2a) or (2b) holds. Let us first prove the former case, where we have
- (4)
.
Hence we have
- (5)
, or
- (6)
.
In the case of (5), the proof is exactly the same as above. In the case of (6), we have
Lemma 5.7 (S-Condition Satisfaction).
For each -node and each stage , -Condition holds.
Proof.
Fixing an , we show that -Condition holds at stage .
Suppose that is -node, where is the -node, is the -node and is the -node. We write and . Let be the last -stage when we defined (and has not been initialized between and ). Since -Condition trivially holds if , we assume . We have
- (1)
and
- (2)
.
As a consequence of (2), we do not visit for between and . By Lemma 2.5, there exists the unique -node for some and with . We list, if any, all paired -nodes extending as
Let be the established pair for each . By the definition of pairing parameter (Section 3 and Subsection 4.4), we have
- (3)
.
Corresponding to clauses (2a) and (2b) in -Condition (see Definition 5.5), our proof splits into two cases.
Case 1. Suppose . We show . Let be the least stage between and at which some number enters and some -node receives attention. The goal is to show that will not enumerate any point less than into . First of all, by the choice of , we have
- (4)
.
We may assume that extends for some as other cases are simpler. Suppose that and are two diagonalizing witnesses of .
Claim 1.
.
Proof of Claim 1.
If , the diagonalizing witnesses (particularly, ) of is larger than , which contradicts our assumption.
Now we show . We have by the assumption of Case 1 and (3). By -DisarmingProcess (DP-4), has been disarmed by (and for are also initialized). As we do not visit between and , we have .
∎
By Claim 1 and the definition of (see Section 3), we have . Therefore we have by (1). By (2) and (4) respectively, we have
- (5)
, and
- (6)
.
Claim 2.
For each , .
Proof of Claim 2.
By Claim 2 we have . In particular, and therefore will not enumerate into . Hence we have , which completes the proof of Case 1.
Case 2. Suppose . Depending on whether or changes first, we have two subcases.
Case 2(a). changes first. We are to show . First of all, let be the least stage between and such that and . As we have by (3), we have , which triggers -DisarmingProcess (DP-2) at and therefore is disarmed (and for are initialized). Let be a -node receiving attention (say, enters ) between and , extending for some . By an argument similar to Claim 1 and Claim 2, we conclude . Hence .
Case 2(b). changes first. We are to show . Let be the least stage between and such that and . We first examine what happens at . Let be the -node who is responsible for this change. That is, receives attention (say, enters ) at with and therefore enumerates its diagonalizing witness into at .
Claim 3.
extends .
Proof of Claim 3.
Suppose that extends for some . If , then we have , contradicting the assumption. If , by a similar argument in Claim 2, we conclude , contradicting . ∎
By Claim 3, we have for some . Therefore, we have
Let be the least stage between and such that enters and some P-node receives attention with diagonalizing witnesses and . Suppose that extends for some . We have
Claim 4.
and .
Proof of Claim 4.
By Claim 4, we have and . Now we have
- (10)
(by (8)), and
- (11)
(by the choice of ).
From (10) and (11), following the argument in Claim 2, we have for each . Hence, we have . In particular, and therefore will not enumerate into . Hence we have . By (3), we have . Hence we have . This completes the proof of Case 2(b) and the proof of this lemma. ∎
5.3. Proof of the main theorem
The goal is to show that has an infinite path. The following notations will be convenient in the proof. For a global parameter , we say that is stable after stage if for each , . A pair is stable after stage if it will not get canceled after stage . If is stable after , then is stable after if for each , . or being stable are defined similarly. A set is stable after if for each we have .
Lemma 5.8.
Let be a node.
- (1)
Suppose that is a -node. Then .
- (2)
Suppose that is a -node and . Then .
- (3)
Suppose that is a -node. Then is recursive.
- (4)
Suppose that is a -node. Then is recursive.
- (5)
Suppose that is a -node and . Then .
- (6)
Suppose that is an -node. Let and . If is the leftmost outcome that is visited infinitely often, then where if respectively; if all outcomes are visited finitely often, then .
- (7)
Suppose that is an -node. Let and . If is the leftmost outcome that is visited infinitely often, then where if respectively; if all outcomes are visited finitely often, then .
- (8)
Suppose that is an -node. Let . If is the leftmost outcome that is visited infinitely often, then ; if all outcomes are visited finitely often, then .
- (9)
Suppose that is a -node. If the leftmost outcome that is visited infinitely often is a -outcome or a -outcome, then . ∎
Lemma 5.9.
Suppose that is a -node such that and for each . Suppose that is a -node such that and is initialized finitely often. Then is disarmed finitely often.
Proof.
Let . Let be the last stage when is initialized (and is not going to be initialized since ). Suppose that is not visited after , it is not paired and therefore it is not going be disarmed. Therefore we assume that is visited after and is the stable pair. Consider -DisarmingProcess for some -node . We show that -DisarmingProcess can be triggered finitely often.
Note first that since is not initialized after , we are not going to visit any node extending with . Therefore the edge parameter is stable for .
Case 1. Suppose that for each , is visited finitely often. Then (DP-1) and (DP-3) are triggered finitely often. Since we also have and stable, (DP-5), (DP-2) and (DP-4) are triggered finitely often.
Case 2. Suppose that is the least such that is visited infinitely often toward a contradiction. Since , is initialized infinitely often. Let be the least such that is initialized infinitely often. As for each , is visited finitely often, only (P2) or (P3) are possible to initialize infinitely often. Suppose that (P2) happens after . If , then would be initialized, contradicting the choice of ; if , then must have been canceled, contradicting that is a stable pair. We are left with the possibility that (P3) happens infinitely often. We assume that is the pair that triggers (P3) infinitely often. If , then announcing progress would initialize , contradicting the choice of ; if , then , contradicting . ∎
Lemma 5.10.
Suppose that is a -node such that and for each . Suppose that is a node such that and is not a -node and is the leftmost outcome that is visited infinitely often. Then .
Proof.
Let be the least stage after which is not initialized (as ). Let be the least stage after which nodes (in ) to the left of
- (1)
are never visited (by the choice of ),
- (2)
never become activated,
- (3)
never receive attention (as the definitions of -functionals of -node are not going be extended),
- (4)
are never initialized, and
- (5)
are never disarmed (by Lemma 5.9 and (4) above).
Referring to Definition 4.1, we conclude that nodes (in ) to the left of will not announce progress after and therefore will not be initialized after . If is not a -node, then we immediately have ; if is a -node, we use Lemma 5.9 to conclude that is disarmed only finitely often and hence .
This completes the proof. ∎
Lemma 5.11.
Suppose , then has an infinite path.
Proof.
Proof.
6. Finding the index of a solution
Theorem 6.1.
Given r.e. sets and with , there is a function such that and .
Proof.
Let be the true path (Definition 5.1). We use to decide if or not. If , we define . If , we will use to decide which set is good (as defined in the first line of the proof of Lemma 2.1).
First of all, the jump of and hence can compute the true path . Next, we use to decide whether there is a -node with . Note that there can be at most one such -node. Case (i), such -node exists. With as a parameter, becomes . We start with and use to decide whether there are infinitely many nodes such that . If yes, define to be the index of ; if not, we proceed to the next node in and repeat. This procedure terminates by Lemma 2.1. Case (ii), Such -node does not exist. By a similar argument, the index of the good set can be found using . ∎
In fact, with a very short proof, we are able to exhibit such an without referring to a concrete construction.
Another proof.
Remark.
In general, deciding whether a set like is empty requires ; what we have showed is that this is in fact a question.
Next we prove that no function can compute the correct index. Consequently, high level of non-uniformity is necessary for the construction.
Theorem 6.2.
Given , there are two r.e. sets and with such that or (i.e., ).
Let us first recall from [1] of what can be done and what can not be done. In [1], they were trying to build two r.e. sets and so that and for all we have . In fact, they developed a successful technique so that for any fixed , they could build two r.e. sets and with so that . The conflicts between three and more sets, however, were overlooked. Fortunately we do not need their technique here to exhibit Theorem 6.2. We only need the fact that for each fixed we can build and with and . This construction can be done by a simple priority argument. The exact details are not critical in proving Theorem 6.2; we just need the construction to be simple enough.
This paragraph serves as a reminder for readers who are interested in the construction. Fixing an index , we are building two r.e. sets and so that the following requirements for each are satisfied:
- •
;
- •
.
The conflict is between the -functionals and -nodes. When an -node wants to enumerate a diagonalizing point, say , into , it enumerates the point. Then an expansionary stage of -node will tell us whether there is a small change in . If there is one, then is undefined without a -change (-node is happy) and we redefine it with a fresh use; otherwise, -node loses its diagonalizing point but it can extend the definition of . The construction has no more conflicts as is the same set throughout the construction and hence one particular wins all -requirements for all ; this feature is indispensable for this construction. This construction is referred as basic construction with parameter and the priority tree will be denoted by .
Now let us do the first warm-up to Theorem 6.2 by assuming the given recursive.
Sketch of the proof for .
We are building two sets and . By recursion theorem we know the indices and for and to be constructed. Then we do the basic construction with parameter to get and with and . ∎
As we can see from the proof, we simply apply the basic construction with the correct parameter to construct and . If is recursive, we immediately compute for the correct parameter. However, if is not recursive, we have to guess the value of . Sometimes we run the basic construction with a wrong parameter, sometimes with the correct one. We have to ensure that the basic construction with correct parameter is not interrupted by those with wrong ones: the idea is that the basic construction is fairly simple and the conflicts between basic constructions with different parameters are not fatal. Now we do the second warm-up for the double jump (we skip the warm-up for the jump).
Sketch of the proof for .
Using recursion theorem we know the indices and for the sets we are constructing. We have to guess what is. Since , so the relation is both and . Let and be recursive predicates such that
and
where and and we suppress the parameters and .
Then we define the guessing tree to guide our construction. The root is assigned . A -node has outcomes ordered by . Each is a terminal node and is assigned .
At each stage , we begin with , where has the following strategy:
Suppose that is an -node.
- (1)
Let be the least, if any, such that happens or happens.
- (2)
If happens, .
- (3)
If happens, .
Suppose that is for some -node . We for the root in , where is a copy of the priority tree for the basic construction with parameter and is a parameter from . (We think of the terminal node of as an entrance to the priority tree for the basic construction with corresponding parameters.)
We have the usual left-to-right initializations: if is initialized (because a node to the left is visited), then all nodes of are initialized.
The true path of is the leftmost path that is visited infinitely often. If , then ; if , then . Therefore is finite. Let be the longest node of , then is visited infinitely often. Note that each node along the true path of is initialized still only finitely often. ∎
If , with different and have no conflicts other than left-to-right initializations. This will not be the case when . We present the main ideas to overcome the conflicts and to avoid overburdening the readers with technical details.
Sketch of the proof for Theorem 6.2.
Using the limit lemma, we know
for some , therefore can be guessed using the same process as in the above proof.
We now define our guessing tree : the root is assigned . Suppose that is assigned , it has outcomes ordered as . is assigned and is assigned . If is the true path along , we have that for some if and only if .
As we travel along the guessing tree and visit a node , we better allow the basic construction with parameter to run. But as our guessing tree is more complicated and two nodes might have guessed for different parameters , these two basic constructions with parameters and have to find ways to cooperate.
The predecessor of is the longest node , if any, such that for some . A -node is an entrance to the basic construction with parameter if its predecessor is not a -node. For , we let
be the sequence such that is an entrance for the basic construction with parameter and is the predecessor of and suppose that is a -node (so is a -node). For each outcome of , we let extend by copying the nodes in of length , where is the priority tree for the basic construction with parameter . The idea is that at we are only allowed to visit a node with length : the algorithm for is paused whenever has length . We let denote the paused node. Whenever we in the guessing tree , we simultaneously for the node .
The initialization is the usual left-to-right kind: if we are visiting a node to the left of , then the nodes in are initialized.
To avoid conflicts between different basic constructions, each entrance picks a fresh point for each . Whenever we for some , we enumerate into to undefine all the -functionals built by some for some .
By a routine verification, one derives the following:
- (1)
The true path of is infinite and there is an infinite sequence
such that , is an entrance for the basic construction with parameter , is a -node for each for some , and is the predecessor of .
- (2)
For each , nodes in the tree are visited infinitely often and initialized finitely often.
- (3)
The union of all is a full copy of , the priority tree for the basic construction with parameter .
This completes the proof. ∎
Acknowledgement
The authors received helpful advice from many peoples during the years when we were working on this paper, and they would like to thank George Barmpalias, Yun Fan, Steffen Lempp, Keng Meng Ng, Theodore Slaman and Liang Yu for valuable discussions and their useful comments.
References
- [1] Barmpalias, George; Cai, Mingzhong; Lempp, Steffen; Slaman, Theodore A. On the existence of a strong minimal pair. J. Math. Log., 15 (2015), no. 1, 1550003, 28 pp.
- [2] Shore, Richard A. A noninversion theorem for the jump operator. Ann. Pure Appl. Logic, 40 (1988), no. 3, 277–303.
- [3] Shore, Richard A., and Slaman, Theodore A. Working below a high recursively enumerable degree. J. of Sym. Logic, 58 (1993), pp. 824–859.